package Data::Unixish::ANSI;

our $DATE = '2015-08-17'; # DATE
our $VERSION = '0.06'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: dux functions related to text containing ANSI codes

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Unixish::ANSI - dux functions related to text containing ANSI codes

=head1 VERSION

This document describes version 0.06 of Data::Unixish::ANSI (from Perl distribution Data-Unixish-ANSI), released on 2015-08-17.

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 SEE ALSO

L<Data::Unixish>

L<dux>

L<Text::ANSI::Util>

L<Term::ANSIColor>

L<Term::ANSIScreen>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish-ANSI>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish-ANSI>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
